@@ -1,8 +1,8 @@
-from .parse import FicusDict
+from .parse import ConfigDict
 
 
 def inherit(config):  # noqa C901
-    '''
+    """
     ficus.inherit pushes the configuration values of
     parent section down to its child sections.
 
@@ -24,7 +24,8 @@ def inherit(config):  # noqa C901
     subject=[Alert] Error
     body=error_template.txt
 
-    '''
+    """
+
     def _inherit(inheritable_options, section):
         # first inherit any options
         # that do not exist
@@ -35,12 +36,12 @@ def inherit(config):  # noqa C901
         # on the section
         section_options = {}
         for key, val in section.items():
-            if not isinstance(val, FicusDict):
+            if not isinstance(val, ConfigDict):
                 section_options[key] = val
         # finally, push down the sections options
         # to all its sub-sections
         for key, val in section.items():
-            if isinstance(val, FicusDict):
+            if isinstance(val, ConfigDict):
                 _inherit(section_options, val)
 
     _inherit({}, config)
